[llvm] [libsycl] Generic code cleanup (PR #224330)

Alexey Bader via llvm-commits llvm-commits at lists.llvm.org
Thu Oct 1 07:55:01 PDT 2026


================
@@ -14,33 +6,33 @@
 #include <sycl/sycl.hpp>
 
 void test(sycl::queue Q) {
-  Q.parallel_for<class barrier_kernel>(
+  Q.parallel_for<class BarrierKernel>(
       sycl::nd_range<1>{8, 4}, [=](sycl::nd_item<1> It) {
         // Execution scope is Workgroup (2), memory scope defaults to the
         // group's fence_scope, i.e. Workgroup (2).
-        // CHECK: call spir_func void @_Z22__spirv_ControlBarrierjjj(i32 noundef
-        // 2, i32 noundef 2, i32 noundef 400)
+        // CHECK: call spir_func void @_Z22__spirv_ControlBarrierjjj(
+        // CHECK-SAME: i32 noundef 2, i32 noundef 2, i32 noundef 400)
----------------
bader wrote:

Why can't we use one-line check?

https://github.com/llvm/llvm-project/pull/224330


More information about the llvm-commits mailing list